/*
 * No rights reserved, this code can be used or modified for any purpose, without acknowledgement.
 */

package com.arjuna.jboss.tests.resources;

import java.io.Serializable;
import javax.transaction.xa.Xid;
import javax.transaction.xa.XAResource;
import javax.transaction.xa.XAException;
import org.jboss.logging.Logger;

public class CrashXAResource implements XAResource, Serializable
{
    private static final long serialVersionUID = 1983645080871787943L;

    public CrashXAResource()
    {
        _crashInPrepare  = false;
        _crashInRollback = false;
        _crashInCommit   = false;
    }

    public CrashXAResource(boolean crashInPrepare, boolean crashInRollback, boolean crashInCommit)
    {
        _crashInPrepare  = crashInPrepare;
        _crashInRollback = crashInRollback;
        _crashInCommit   = crashInCommit;
    }

    public void start(Xid xid, int flags)
        throws XAException
    {
        _logger.info("start('" + xid + "', " + flags + ')');
    }
    
    public void end(Xid xid, int flags)
        throws XAException
    {
        _logger.info("end('" + xid + "', " + flags + ')');
    }

    public int prepare(Xid xid)
        throws XAException
    {
        _logger.info("prepare('" + xid + "')");

        if (_crashInPrepare)
            Runtime.getRuntime().halt(0);

        return XAResource.XA_OK;
    }

    public void commit(Xid xid, boolean onePhase)
        throws XAException
    {
        _logger.info("commit('" + xid + "', " + onePhase + ')');

        if (_crashInCommit)
            Runtime.getRuntime().halt(0);
    }

    public void rollback(Xid xid)
        throws XAException
    {
        _logger.info("rollback('" + xid + "')");

        if (_crashInRollback)
            Runtime.getRuntime().halt(0);
    }

    public void forget(Xid xid)
        throws XAException
    {
        _logger.trace("forget('" + xid + "')");
    }

    public Xid[] recover(int flags)
       throws XAException
    {
        return new Xid[0];
    }

    public boolean isSameRM(XAResource xaResource)
        throws XAException
    {
        return (this == xaResource);
    }

    public int getTransactionTimeout()
        throws XAException
    {
        return _timeout;
    }

    public boolean setTransactionTimeout(int timeout)
        throws XAException
    {
        _timeout = timeout;

        return true;
    }

    private int _timeout = 100;

    private transient boolean _crashInPrepare;
    private transient boolean _crashInRollback;
    private transient boolean _crashInCommit;

    private static Logger _logger = Logger.getLogger(CrashXAResource.class);
}
